==> igniteui-react-charts-18.7.0-beta.2.tgz: package/esm5/lib/VerticalAnchoredCategorySeriesInteractionManager.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, Point_$type, markType } from "igniteui-react-core";
import { IVerticalAnchoredCategorySeriesInteractionManager_$type } from "./IVerticalAnchoredCategorySeriesInteractionManager";
import { Rect } from "igniteui-react-core";
import { ScalerParams } from "./ScalerParams";
import { ArrayExtension } from "igniteui-react-core";
/**
 * @hidden
 */
var VerticalAnchoredCategorySeriesInteractionManager = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(VerticalAnchoredCategorySeriesInteractionManager, _super);
    function VerticalAnchoredCategorySeriesInteractionManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    VerticalAnchoredCategorySeriesInteractionManager.prototype.e$a = function (a, b) {
        var c = a.c9 != null ? a.c9.vl : Rect.empty;
        var d = a.ct.bx;
        var e = a.wc(a.ct);
        var f = a.getEffectiveViewport1(a.ct);
        var g = a.az();
        var h = -1;
        if (g != null && !c.isEmpty && !d.isEmpty) {
            var i = new ScalerParams(0, c, d, g.ch, f);
            var j = g.en(e.top, i);
            var k = g.en(e.bottom, i);
            var l = (b.y - c.top) / c.height;
            var m = j + (l * (k - j));
            if (g.categoryMode != 0) {
                m -= 0.5;
            }
            h = m;
        }
        return h;
    };
    VerticalAnchoredCategorySeriesInteractionManager.prototype.e$b = function (a, b, c, d) {
        if (b == null || b.count == 0) {
            return Rect.empty;
        }
        var e = a.v0(c);
        var f = -1;
        var g = a.az().ch;
        var h = a.ct.bx.bottom * 2;
        if (g) {
            f = ArrayExtension.binarySearch$11(Point_$type, b, function (i) { return (h - e.y) < (h - i.y) ? -1 : ((h - e.y) > (h - i.y) ? 1 : 0); });
        }
        else {
            f = ArrayExtension.binarySearch$11(Point_$type, b, function (i) { return e.y < i.y ? -1 : (e.y > i.y ? 1 : 0); });
        }
        if (f < 0) {
            f = ~f;
        }
        if (f < 0) {
            f = 0;
        }
        if (f > b.count - 1) {
            f = b.count - 1;
        }
        var i = f;
        var j = f;
        if (i > 0) {
            i--;
        }
        if (j < b.count - 1) {
            j++;
        }
        var k = b._inner[i].y;
        var l = b._inner[f].y;
        var m = b._inner[j].y;
        var n = Math.abs(k - e.y);
        var o = Math.abs(l - e.y);
        var p = Math.abs(m - e.y);
        var q = d(i);
        var r = d(f);
        var s = d(j);
        var t = q.containsPoint(e);
        var u = r.containsPoint(e);
        var v = s.containsPoint(e);
        if (o <= n && o <= p) {
            if (!g && v) {
                return s;
            }
            if (g && t) {
                return q;
            }
            return r;
        }
        if (n <= o && n <= p) {
            if (!g && u) {
                return r;
            }
            return d(i);
        }
        if (p <= o && p <= n) {
            if (g && u) {
                return r;
            }
            return d(j);
        }
        return Rect.empty;
    };
    VerticalAnchoredCategorySeriesInteractionManager.$t = markType(VerticalAnchoredCategorySeriesInteractionManager, 'VerticalAnchoredCategorySeriesInteractionManager', Base.$, [IVerticalAnchoredCategorySeriesInteractionManager_$type]);
    return VerticalAnchoredCategorySeriesInteractionManager;
}(Base));
export { VerticalAnchoredCategorySeriesInteractionManager };

==> igniteui-react-charts-18.7.5-beta.2.tgz: package/esm5/lib/VerticalAnchoredCategorySeriesInteractionManager.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, Point_$type, markType } from "igniteui-react-core";
import { IVerticalAnchoredCategorySeriesInteractionManager_$type } from "./IVerticalAnchoredCategorySeriesInteractionManager";
import { Rect } from "igniteui-react-core";
import { ScalerParams } from "./ScalerParams";
import { ArrayExtension } from "igniteui-react-core";
/**
 * @hidden
 */
var VerticalAnchoredCategorySeriesInteractionManager = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(VerticalAnchoredCategorySeriesInteractionManager, _super);
    function VerticalAnchoredCategorySeriesInteractionManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    VerticalAnchoredCategorySeriesInteractionManager.prototype.e$a = function (a, b) {
        var c = a.db != null ? a.db.v4 : Rect.empty;
        var d = a.cv.bx;
        var e = a.wj(a.cv);
        var f = a.getEffectiveViewport1(a.cv);
        var g = a.a0();
        var h = -1;
        if (g != null && !c.isEmpty && !d.isEmpty) {
            var i = new ScalerParams(0, c, d, g.ch, f);
            var j = g.eo(e.top, i);
            var k = g.eo(e.bottom, i);
            var l = (b.y - c.top) / c.height;
            var m = j + (l * (k - j));
            if (g.categoryMode != 0) {
                m -= 0.5;
            }
            h = m;
        }
        return h;
    };
    VerticalAnchoredCategorySeriesInteractionManager.prototype.e$b = function (a, b, c, d) {
        if (b == null || b.count == 0) {
            return Rect.empty;
        }
        var e = a.v7(c);
        var f = -1;
        var g = a.a0().ch;
        var h = a.cv.bx.bottom * 2;
        if (g) {
            f = ArrayExtension.binarySearch$11(Point_$type, b, function (i) { return (h - e.y) < (h - i.y) ? -1 : ((h - e.y) > (h - i.y) ? 1 : 0); });
        }
        else {
            f = ArrayExtension.binarySearch$11(Point_$type, b, function (i) { return e.y < i.y ? -1 : (e.y > i.y ? 1 : 0); });
        }
        if (f < 0) {
            f = ~f;
        }
        if (f < 0) {
            f = 0;
        }
        if (f > b.count - 1) {
            f = b.count - 1;
        }
        var i = f;
        var j = f;
        if (i > 0) {
            i--;
        }
        if (j < b.count - 1) {
            j++;
        }
        var k = b._inner[i].y;
        var l = b._inner[f].y;
        var m = b._inner[j].y;
        var n = Math.abs(k - e.y);
        var o = Math.abs(l - e.y);
        var p = Math.abs(m - e.y);
        var q = d(i);
        var r = d(f);
        var s = d(j);
        var t = q.containsPoint(e);
        var u = r.containsPoint(e);
        var v = s.containsPoint(e);
        if (o <= n && o <= p) {
            if (!g && v) {
                return s;
            }
            if (g && t) {
                return q;
            }
            return r;
        }
        if (n <= o && n <= p) {
            if (!g && u) {
                return r;
            }
            return d(i);
        }
        if (p <= o && p <= n) {
            if (g && u) {
                return r;
            }
            return d(j);
        }
        return Rect.empty;
    };
    VerticalAnchoredCategorySeriesInteractionManager.$t = markType(VerticalAnchoredCategorySeriesInteractionManager, 'VerticalAnchoredCategorySeriesInteractionManager', Base.$, [IVerticalAnchoredCategorySeriesInteractionManager_$type]);
    return VerticalAnchoredCategorySeriesInteractionManager;
}(Base));
export { VerticalAnchoredCategorySeriesInteractionManager };
